Function slow_primes::is_prime_miller_rabin
[-] [+]
[src]
pub fn is_prime_miller_rabin(n: u64) -> bool
Test if n is prime, using the deterministic version of the
Miller-Rabin test.
Doing a lot of primality tests with numbers strictly below some
upper bound will be faster using the is_prime method of a
Primes instance.